==> com.liferay.site.navigation.admin.web-3.0.24.jar: META-INF/resources/site_navigation_menu_editor/components/MenuSettingsPanel.js <==
Liferay.Loader.define("site-navigation-admin-web@3.0.24/site_navigation_menu_editor/components/MenuSettingsPanel", ['module', 'exports', 'require', 'frontend-js-react-web$react', '../contexts/ConstantsContext', './SidebarPanelContent'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.MenuSettingsPanel = MenuSettingsPanel;

    var _react = _interopRequireDefault(require("frontend-js-react-web$react"));

    var _ConstantsContext = require("../contexts/ConstantsContext");

    var _SidebarPanelContent = require("./SidebarPanelContent");

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { "default": obj };
    }

    /**
     * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
     *
     * This library is free software; you can redistribute it and/or modify it under
     * the terms of the GNU Lesser General Public License as published by the Free
     * Software Foundation; either version 2.1 of the License, or (at your option)
     * any later version.
     *
     * This library is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
     * details.
     */
    function MenuSettingsPanel() {
      var _useConstants = (0, _ConstantsContext.useConstants)(),
          editSiteNavigationMenuSettingsURL = _useConstants.editSiteNavigationMenuSettingsURL,
          siteNavigationMenuId = _useConstants.siteNavigationMenuId,
          siteNavigationMenuName = _useConstants.siteNavigationMenuName;

      return _react["default"].createElement(_SidebarPanelContent.SidebarPanelContent, {
        contentRequestBody: {
          siteNavigationMenuId: siteNavigationMenuId
        },
        contentUrl: editSiteNavigationMenuSettingsURL,
        title: siteNavigationMenuName
      });
    }
    //# sourceMappingURL=MenuSettingsPanel.js.map
  }
});
//# sourceMappingURL=MenuSettingsPanel.js.map

==> com.liferay.site.navigation.admin.web-3.0.35.jar: META-INF/resources/site_navigation_menu_editor/components/MenuSettingsPanel.js <==
Liferay.Loader.define("site-navigation-admin-web@3.0.35/site_navigation_menu_editor/components/MenuSettingsPanel", ['module', 'exports', 'require', 'frontend-js-react-web$react', '../contexts/ConstantsContext', './SidebarPanelContent'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.MenuSettingsPanel = MenuSettingsPanel;

    var _react = _interopRequireDefault(require("frontend-js-react-web$react"));

    var _ConstantsContext = require("../contexts/ConstantsContext");

    var _SidebarPanelContent = require("./SidebarPanelContent");

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { default: obj };
    }

    /**
     * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
     *
     * This library is free software; you can redistribute it and/or modify it under
     * the terms of the GNU Lesser General Public License as published by the Free
     * Software Foundation; either version 2.1 of the License, or (at your option)
     * any later version.
     *
     * This library is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
     * details.
     */
    function MenuSettingsPanel() {
      var _useConstants = (0, _ConstantsContext.useConstants)(),
          editSiteNavigationMenuSettingsURL = _useConstants.editSiteNavigationMenuSettingsURL,
          siteNavigationMenuId = _useConstants.siteNavigationMenuId,
          siteNavigationMenuName = _useConstants.siteNavigationMenuName;

      return (/*#__PURE__*/_react.default.createElement(_SidebarPanelContent.SidebarPanelContent, {
          contentRequestBody: {
            siteNavigationMenuId: siteNavigationMenuId
          },
          contentUrl: editSiteNavigationMenuSettingsURL,
          title: siteNavigationMenuName
        })
      );
    }
    //# sourceMappingURL=MenuSettingsPanel.js.map
  }
});
//# sourceMappingURL=MenuSettingsPanel.js.map
